#[unsafe(no_mangle)]pub unsafe extern "C" fn wait(stat_loc: *mut c_int) -> pid_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/wait.html.
Obtains status information pertaining to one of the caller’s child processes.
If returning because the status of a child process is available, returns a
value equal to the process ID of the child process for which status is
reported. If returning due to the delivery of a signal to the calling
process, returns -1 and sets errno to EINTR. If otherwise failing,
returns -1 and sets errno.